@@ -14,7 +14,7 @@ sub run {
 	
 	# main loop
 	foreach my $chromosome (@{$ga->{chromosomes}}){
-		next if rand() <= $mutation;
+		next if rand() >= $mutation;
 		my $idx = int rand @$chromosome;
 		$chromosome->[$idx] = int rand @{$ga->_translations->[$idx]};
 	}
